==> babel-preset-lib-1.13.3.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [1.13.3](https://github.com/open-data-plan/pangu/compare/v1.13.2...v1.13.3) (2020-11-17)

**Note:** Version bump only for package @opd/babel-preset-lib





## [1.12.1](https://github.com/open-data-plan/pangu/compare/v1.12.0...v1.12.1) (2020-11-10)

**Note:** Version bump only for package @opd/babel-preset-lib





## [1.11.3](https://github.com/open-data-plan/pangu/compare/v1.11.2...v1.11.3) (2020-10-19)

**Note:** Version bump only for package @opd/babel-preset-lib





# [1.11.0](https://github.com/open-data-plan/pangu/compare/v1.10.1...v1.11.0) (2020-10-16)


### Features

* compatible with webpack 5 ([fa56bfe](https://github.com/open-data-plan/pangu/commit/fa56bfee85001691f09d58375f290fe9f101cd95))





## [1.10.1](https://github.com/open-data-plan/pangu/compare/v1.10.0...v1.10.1) (2020-10-12)

**Note:** Version bump only for package @opd/babel-preset-lib





# [1.10.0](https://github.com/open-data-plan/pangu/compare/v1.9.2...v1.10.0) (2020-10-12)

**Note:** Version bump only for package @opd/babel-preset-lib





## [1.8.3](https://github.com/open-data-plan/pangu/compare/v1.8.2...v1.8.3) (2020-09-14)

**Note:** Version bump only for package @opd/babel-preset-lib





## [1.8.2](https://github.com/open-data-plan/pangu/compare/v1.8.1...v1.8.2) (2020-08-25)

**Note:** Version bump only for package @opd/babel-preset-lib





# [1.6.0](https://github.com/open-data-plan/pangu/compare/v1.5.1...v1.6.0) (2020-08-08)

**Note:** Version bump only for package @opd/babel-preset-lib





# [1.5.0](https://github.com/open-data-plan/pangu/compare/v1.4.1...v1.5.0) (2020-06-24)

**Note:** Version bump only for package @opd/babel-preset-lib





## [1.4.1](https://github.com/open-data-plan/pangu/compare/v1.4.0...v1.4.1) (2020-06-15)

**Note:** Version bump only for package @opd/babel-preset-lib





# [1.3.0](https://github.com/open-data-plan/pangu/compare/v1.2.0...v1.3.0) (2020-05-21)


### Bug Fixes

* update babel config ([6a32f14](https://github.com/open-data-plan/pangu/commit/6a32f14e85c0ce506f70d5894abfc65c021a3f73))





# [1.2.0](https://github.com/open-data-plan/pangu/compare/v1.1.0...v1.2.0) (2020-05-21)

**Note:** Version bump only for package @opd/babel-preset-lib





# [1.1.0](https://github.com/open-data-plan/pangu/compare/v1.0.0...v1.1.0) (2020-04-09)

**Note:** Version bump only for package @opd/babel-preset-lib





# 0.1.0 (2020-04-02)


### Features

* initial repo ([4af6861](https://github.com/open-data-plan/pangu/commit/4af68610cae7d78784c7b2e0d4675365b18cc106))

==> babel-preset-lib-1.13.4.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [1.13.4](https://github.com/open-data-plan/pangu/compare/v1.13.3...v1.13.4) (2021-01-26)

**Note:** Version bump only for package @opd/babel-preset-lib

## [1.13.3](https://github.com/open-data-plan/pangu/compare/v1.13.2...v1.13.3) (2020-11-17)

**Note:** Version bump only for package @opd/babel-preset-lib

## [1.12.1](https://github.com/open-data-plan/pangu/compare/v1.12.0...v1.12.1) (2020-11-10)

**Note:** Version bump only for package @opd/babel-preset-lib

## [1.11.3](https://github.com/open-data-plan/pangu/compare/v1.11.2...v1.11.3) (2020-10-19)

**Note:** Version bump only for package @opd/babel-preset-lib

# [1.11.0](https://github.com/open-data-plan/pangu/compare/v1.10.1...v1.11.0) (2020-10-16)

### Features

- compatible with webpack 5 ([fa56bfe](https://github.com/open-data-plan/pangu/commit/fa56bfee85001691f09d58375f290fe9f101cd95))

## [1.10.1](https://github.com/open-data-plan/pangu/compare/v1.10.0...v1.10.1) (2020-10-12)

**Note:** Version bump only for package @opd/babel-preset-lib

# [1.10.0](https://github.com/open-data-plan/pangu/compare/v1.9.2...v1.10.0) (2020-10-12)

**Note:** Version bump only for package @opd/babel-preset-lib

## [1.8.3](https://github.com/open-data-plan/pangu/compare/v1.8.2...v1.8.3) (2020-09-14)

**Note:** Version bump only for package @opd/babel-preset-lib

## [1.8.2](https://github.com/open-data-plan/pangu/compare/v1.8.1...v1.8.2) (2020-08-25)

**Note:** Version bump only for package @opd/babel-preset-lib

# [1.6.0](https://github.com/open-data-plan/pangu/compare/v1.5.1...v1.6.0) (2020-08-08)

**Note:** Version bump only for package @opd/babel-preset-lib

# [1.5.0](https://github.com/open-data-plan/pangu/compare/v1.4.1...v1.5.0) (2020-06-24)

**Note:** Version bump only for package @opd/babel-preset-lib

## [1.4.1](https://github.com/open-data-plan/pangu/compare/v1.4.0...v1.4.1) (2020-06-15)

**Note:** Version bump only for package @opd/babel-preset-lib

# [1.3.0](https://github.com/open-data-plan/pangu/compare/v1.2.0...v1.3.0) (2020-05-21)

### Bug Fixes

- update babel config ([6a32f14](https://github.com/open-data-plan/pangu/commit/6a32f14e85c0ce506f70d5894abfc65c021a3f73))

# [1.2.0](https://github.com/open-data-plan/pangu/compare/v1.1.0...v1.2.0) (2020-05-21)

**Note:** Version bump only for package @opd/babel-preset-lib

# [1.1.0](https://github.com/open-data-plan/pangu/compare/v1.0.0...v1.1.0) (2020-04-09)

**Note:** Version bump only for package @opd/babel-preset-lib

# 0.1.0 (2020-04-02)

### Features

- initial repo ([4af6861](https://github.com/open-data-plan/pangu/commit/4af68610cae7d78784c7b2e0d4675365b18cc106))
